Welcome to dicom_parser’s documentation! — dicom_parser 0.0.1 documentation

# Welcome to dicom_parser’s documentation!

# Overview

dicom_parser is a utility python package meant to facilitate access to DICOM header information by extending the functionality of pydicom.

Essentially, dicom_parser uses DICOM’s data-element value-representation (VR), as well as prior knowledge on vendor-specific private tags or encoding schemes, in order to transform them to more “pythonic” data structures when possible.

# Installation

To install the latest version of dicom_parser, simply run:

    pip install dicom_parser

Contents:

- Quickstart
  - Coversion to Python’s native types
  - Read DICOM series directory as a `Series`
- Vendor-specific Information
  - Siemens
- Reference
  - dicom_parser package
- Release Notes
  - 0.1.3
  - 0.1.2
  - 0.1.1
  - 0.1.0

# Indices and tables

- Index

- Module Index

- Search Page